==> nextcloud-30.0.13.tgz: nextcloud/apps/circles/l10n/es_MX.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipos",
    "You created the team {circle}" : "Ha creado el equipo {circle}",
    "{author} created the team {circle}" : "{author} creó el equipo {circle}",
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You made {member} join {circle}" : "Ha hecho que {member} se una a {circle}",
    "{author} made {member} join {circle}" : "{author} ha hecho que {member} se una a {circle}",
    "You added team {member} as member to {circle}" : "Ha añadido al equipo {member} como miembro de {circle}",
    "You made {member} leave {circle}" : "Ha hecho que {member} deje {circle}",
    "{author} made {member} leave {circle}" : "{author} ha hecho que {member} deje {circle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "{member} cancelled a request to join {circle}" : "{member} canceló una solicitud para unirse a {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que ocurren en un <strong>equipo</strong> del cual es miembro",
    "Any important event in a <strong>team</strong> you are moderating" : "Cualquier evento importante en un <strong>equipo</strong> que esté moderando",
    "On global events happening in any <strong>team</strong>" : "En eventos globales que ocurren en cualquier <strong>equipo</strong>",
    "Single" : "Individual",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Invite" : "Invitar",
    "Join request" : "Solicitud de unirse",
    "Friends" : "Amigos",
    "Password protected" : "Protegido con contraseña",
    "No Owner" : "Sin propietario",
    "Hidden" : "Oculto",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Raíz",
    "Team invite" : "Invitación de equipo",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaje",
    "Nextcloud Account" : "Cuenta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Nextcloud App" : "Aplicación de Nextcloud",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s shared »%s« with \"%s\"." : "%s compartió »%s« con \"%s\".",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió »%2$s« con usted.\nDebería haber recibido un correo electrónico por separado con un enlace de acceso.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartió »%2$s« con usted. Debería haber recibido un correo electrónico por separado con un enlace de acceso.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a »%1$s« compartido con usted por %2$s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartió varios archivos con usted.\nDebería haber recibido un correo electrónico por separado con un enlace de acceso.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartió varios archivos con usted. Debería haber recibido un correo electrónico por separado con un enlace de acceso.",
    "Password to access files shared to you by %1$s" : "Contraseña para acceder a los archivos compartidos con usted por %1$s",
    "Password to access files" : "Contraseña para acceder a los archivos",
    "%s shared multiple files with \"%s\"." : "%s compartió varios archivos con \"%s\".",
    "%s shared multiple files with you." : "%s le compartió varios archivos.",
    "Boot up" : "Arrancar",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Circles App Initialization" : "Inicialización de la aplicación Círculos",
    "Fresh installation status" : "Estado de la nueva instalación",
    "Building Local Database" : "Creando la base de datos local",
    "Testing Basic Circle Creation" : "Probando la creación básica de círculos",
    "Adding local users and moderators" : "Añadiendo usuarios locales y moderadores",
    "Show all teams" : "Mostrar todos los equipos",
    "Create a new team" : "Crear un nuevo equipo",
    "Files" : "Archivo",
    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
    "The team is not federated" : "El equipo no está federado",
    "You cannot join this team" : "No puede unirse a este equipo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "This member is the owner of the team" : "Este miembro es el dueño del equipo",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
    "%s (Team owned by %s)" : "%s (Equipo propiedad de %s)",
    "Accept" : "Aceptar",
    "Refuse" : "Rechazar",
    "%s" : "%s",
    "Personal team" : "Equipo personal",
    "%s owned by %s" : "%s propiedad de %s",
    "You have no permission to create a new team" : "No tiene permiso para crear un nuevo equipo",
    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
    "%s shared a file with you." : "%s le compartió un archivo.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s le compartió contenido.\nDebería haber recibido un correo electrónico por separado con un enlace de acceso.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s le compartió contenido. Debería haber recibido un correo electrónico por separado con un enlace de acceso.",
    "Password to access content shared with you by %1$s" : "Contraseña para acceder al contenido compartido con usted por %1$s",
    "Password to access content" : "Contraseña para acceder al contenido",
    "This item is already shared with this team" : "Este elemento ya está compartido con este equipo",
    "Bring cloud-users closer together." : "Acercando a los usuarisos de nubes.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Los equipos permiten a las personas crear sus propios grupos de personas/compañeros/amigos.\nEstos grupos de personas pueden ser utilizados por cualquier otra aplicación para compartir.",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Teams' files" : "Archivos del equipo",
    "Select team to filter by" : "Selecciona el equipo por el que filtrar",
    "No teams found" : "No se encontraron equipos",
    "Please select teams to filter by" : "Por favor, seleccione los equipos por los que filtrar",
    "No files found for the selected teams" : "No se encontraron archivos para los equipos seleccionados",
    "Shared to Circles" : "Compartido a Círculos"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.11.tgz: nextcloud/apps/circles/l10n/es_MX.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Ha creado el equipo {circle}",
    "{author} created the team {circle}" : "{author} creó el equipo {circle}",
    "You deleted {circle}" : "Borraste el círculo {circle}",
    "{author} deleted {circle}" : "{author} borró {circle}",
    "You made {member} join {circle}" : "Ha hecho que {member} se una a {circle}",
    "{author} made {member} join {circle}" : "{author} ha hecho que {member} se una a {circle}",
    "You added team {member} as member to {circle}" : "Ha añadido al equipo {member} como miembro de {circle}",
    "You made {member} leave {circle}" : "Ha hecho que {member} deje {circle}",
    "{author} made {member} leave {circle}" : "{author} ha hecho que {member} deje {circle}",
    "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
    "You joined {circle}" : "Te uniste a {circle}",
    "{member} joined {circle}" : "{member} se unió a {circle}",
    "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la inivtación para unirse a {circle}",
    "You added {member} as member to {circle}" : "Agregaste a {member} como miembro de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido agregado como miembro de {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} ha sido agregado como un miembro de {circle} por {author}",
    "You added {external} to {circle}" : "Agregaste a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido agregado a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Aceptaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu solicitud para unirte a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La solicitud de {member} para unirse  a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Dejaste el {circle}",
    "{member} left {circle}" : "{member} dejó {circle}",
    "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
    "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
    "{member} cancelled a request to join {circle}" : "{member} canceló una solicitud para unirse a {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Eliminaste a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} ha sido eliminado de {circle} por {autor}",
    "You cancelled {member}'s invitation to join {circle}" : "Cancelaste la invitación de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación para unirte a {circle} ha sido cancelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} canceló la invitación de {member} para unirse a {crcle}",
    "You dismissed {member}'s request to join {circle}" : "Descartaste la solicitud de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu solicitud para unirte a {circle} fue descartada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La solicitud de {member} para unirse a {circle} ha sido descartada por {author}",
    "You invited {member} to join {circle}" : "Invitaste a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "{author} te ha invitado a unirte a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} fue invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Cambiaste el nivel de {member} en el círculo a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambió tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambió el nivel de {member} en {circle}  a %1$s",
    "You sent a request to join {circle}" : "Enviaste una solicitud para unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
    "Teams" : "Equipos",
    "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que ocurren en un <strong>equipo</strong> del cual es miembro",
    "Any important event in a <strong>team</strong> you are moderating" : "Cualquier evento importante en un <strong>equipo</strong> que esté moderando",
    "On global events happening in any <strong>team</strong>" : "En eventos globales que ocurren en cualquier <strong>equipo</strong>",
    "Single" : "Individual",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Invite" : "Invitar",
    "Join request" : "Solicitud de unirse",
    "Friends" : "Amigos",
    "Password protected" : "Protegido con contraseña",
    "No Owner" : "Sin propietario",
    "Hidden" : "Oculto",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Raíz",
    "Team invite" : "Invitación de equipo",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaje",
    "Nextcloud Account" : "Cuenta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Team" : "Equipo",
    "Nextcloud App" : "Aplicación de Nextcloud",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s compartió »%s« contigo.",
    "%s shared »%s« with \"%s\"." : "%s compartió »%s« con \"%s\".",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió »%2$s« con usted.\nDebería haber recibido un correo electrónico por separado con un enlace de acceso.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartió »%2$s« con usted. Debería haber recibido un correo electrónico por separado con un enlace de acceso.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a »%1$s« compartido con usted por %2$s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Haz click en el botón para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartió varios archivos con usted.\nDebería haber recibido un correo electrónico por separado con un enlace de acceso.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartió varios archivos con usted. Debería haber recibido un correo electrónico por separado con un enlace de acceso.",
    "Password to access files shared to you by %1$s" : "Contraseña para acceder a los archivos compartidos con usted por %1$s",
    "Password to access files" : "Contraseña para acceder a los archivos",
    "%s shared multiple files with \"%s\"." : "%s compartió varios archivos con \"%s\".",
    "%s shared multiple files with you." : "%s le compartió varios archivos.",
    "Boot up" : "Arrancar",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Circles App Initialization" : "Inicialización de la aplicación Círculos",
    "Fresh installation status" : "Estado de la nueva instalación",
    "Building Local Database" : "Creando la base de datos local",
    "Adding local users and moderators" : "Añadiendo usuarios locales y moderadores",
    "Show all teams" : "Mostrar todos los equipos",
    "Create a new team" : "Crear un nuevo equipo",
    "Files" : "Archivo",
    "The team is not federated" : "El equipo no está federado",
    "You cannot join this team" : "No puede unirse a este equipo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "This member is the owner of the team" : "Este miembro es el dueño del equipo",
    "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
    "%s (Team owned by %s)" : "%s (Equipo propiedad de %s)",
    "Accept" : "Aceptar",
    "Refuse" : "Rechazar",
    "%s" : "%s",
    "Personal team" : "Equipo personal",
    "%s owned by %s" : "%s propiedad de %s",
    "You have no permission to create a new team" : "No tiene permiso para crear un nuevo equipo",
    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
    "%s shared a file with you." : "%s le compartió un archivo.",
    "Open %s" : "Abrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s le compartió contenido.\nDebería haber recibido un correo electrónico por separado con un enlace de acceso.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s le compartió contenido. Debería haber recibido un correo electrónico por separado con un enlace de acceso.",
    "Password to access content shared with you by %1$s" : "Contraseña para acceder al contenido compartido con usted por %1$s",
    "Password to access content" : "Contraseña para acceder al contenido",
    "This item is already shared with this team" : "Este elemento ya está compartido con este equipo",
    "Bring cloud-users closer together." : "Acercando a los usuarisos de nubes.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Los equipos permiten a las personas crear sus propios grupos de personas/compañeros/amigos.\nEstos grupos de personas pueden ser utilizados por cualquier otra aplicación para compartir.",
    "Try again" : "Reintentar",
    "No teams found" : "No se encontraron equipos",
    "Loading…" : "Cargando...",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Shared to Circles" : "Compartido a Círculos",
    "Testing Basic Circle Creation" : "Probando la creación básica de círculos",
    "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
    "You are already a member of this circle" : "Ya eres un miembro de este círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
